summaryrefslogtreecommitdiffstats
path: root/vm/mterp/out/InterpC-allstubs.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'vm/mterp/out/InterpC-allstubs.cpp')
-rw-r--r--vm/mterp/out/InterpC-allstubs.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/vm/mterp/out/InterpC-allstubs.cpp b/vm/mterp/out/InterpC-allstubs.cpp
index b266e61f0..5a78dc4ad 100644
--- a/vm/mterp/out/InterpC-allstubs.cpp
+++ b/vm/mterp/out/InterpC-allstubs.cpp
@@ -102,7 +102,7 @@
{ \
char* desc; \
desc = dexProtoCopyMethodDescriptor(&curMethod->prototype); \
- LOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
+ ALOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
myoff, (int) (pc - curMethod->insns), \
curMethod->clazz->descriptor, curMethod->name, desc); \
free(desc); \
@@ -321,14 +321,14 @@ static inline bool checkForNull(Object* obj)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -353,14 +353,14 @@ static inline bool checkForNullExportPC(Object* obj, u4* fp, const u2* pc)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -3005,7 +3005,7 @@ HANDLE_OPCODE(OP_UNUSED_FF)
/*
* In portable interp, most unused opcodes will fall through to here.
*/
- LOGE("unknown opcode 0x%02x\n", INST_INST(inst));
+ ALOGE("unknown opcode 0x%02x\n", INST_INST(inst));
dvmAbort();
FINISH(1);
OP_END
@@ -3141,7 +3141,7 @@ GOTO_TARGET(filledNewArray, bool methodCallRange, bool)
GOTO_exceptionThrown();
} else if (typeCh != 'L' && typeCh != '[' && typeCh != 'I') {
/* TODO: requires multiple "fill in" loops with different widths */
- LOGE("non-int primitives not implemented");
+ ALOGE("non-int primitives not implemented");
dvmThrowInternalError(
"filled-new-array not implemented for anything but 'int'");
GOTO_exceptionThrown();
@@ -3658,7 +3658,7 @@ GOTO_TARGET(returnFromMethod)
{
FINISH(3);
} else {
//LOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
}
@@ -4035,7 +4035,7 @@ GOTO_TARGET(invokeMethod, bool methodCallRange, const Method* _methodToCall,
{
FINISH(3);
} else {
//LOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
}
@@ -3658,7 +3658,7 @@ GOTO_TARGET(returnFromMethod)
FINISH(3);
} else {
- //LOGE("Unknown invoke instr %02x at %d",
+ //ALOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
@@ -4035,7 +4035,7 @@ GOTO_TARGET(invokeMethod, bool methodCallRange, const Method* _methodToCall,
FINISH(3);
} else {
- //LOGE("Unknown invoke instr %02x at %d",
+ //ALOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);